Mixed-up Code Questions
-----------------------

.. selectquestion:: variable_mixedupcode_1_sq
   :fromid: var-mixed-1, var-mixed-ac-1q
   :toggle: 


.. selectquestion:: variable_mixedupcode_2_sq
   :fromid: var-mixed-2, var-mixed-ac-2q
   :toggle: 


.. selectquestion:: variable_mixedupcode_3_sq
   :fromid: var-mixed-hours-3, var-mixed-ac-3q
   :toggle: 


.. selectquestion:: variable_mixedupcode_4_sq
   :fromid: var-mixed-price-4, var-mixed-ac-4q
   :toggle: 

.. selectquestion:: variable_mixedupcode_5_sq
   :fromid: var-mixed-tip-5, var-mixed-ac-5q
   :toggle: 

.. selectquestion:: variable_mixedupcode_6_sq
   :fromid: var-mixed-switch-6, var-mixed-switch-ac-6q
   :toggle: 

.. selectquestion:: variable_mixedupcode_7_sq 
   :fromid: var-mixed-discount-7, var-mixed-discount-ac-7q
   :toggle: 

.. selectquestion:: variable_mixedupcode_8_sq
   :fromid: var-mixed-cookies-8, var-mixed-cookies-ac-8q
   :toggle: 

.. selectquestion:: variable_mixedupcode_9_sq
   :fromid: var-mixed-camp-9, var-mixed-camp-ac-9q
   :toggle: 

.. selectquestion:: variable_mixedupcode_10_sq
   :fromid: var-mixed-numbers-10, var-mixed-numbers-ac-10q
   :toggle: